@@ -44,6 +44,10 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 #include "utils/runstats.h"
 #include "ext2spice/ext2spice.h"
 
+/* Hash table global variables defined in ext2spice.c */
+extern HashTable subcktNameTable;
+extern DQueue    subcktNameQueue;
+
 // Structure passed to esHierVisit
 
 typedef struct _defflagsdata {
@@ -1867,6 +1871,15 @@ esHierVisit(hc, cdata)
     esSbckNum = 0;
     esNodeNum = 10;
 
+    /* Make sure instance name-to-number mapping table is cleared */
+    if (esFormat == HSPICE)
+    {
+        HashInit(&subcktNameTable, 32, HT_STRINGKEYS);
+#ifndef UNSORTED_SUBCKT
+        DQInit(&subcktNameQueue, 64);
+#endif
+    }
+
     EFFlatDone();
     return 0;
 }
